==> google-cloud-sdk-528.0.0-darwin-arm.tar.gz: google-cloud-sdk/lib/surface/compute/security_policies/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2017 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Commands for reading and manipulating security policies."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


class SecurityPolicies(base.Group):
  """Read and manipulate Cloud Armor security policies."""
  pass


SecurityPolicies.category = base.LOAD_BALANCING_CATEGORY

SecurityPolicies.detailed_help = {
    'DESCRIPTION': """
       Read and manipulate Cloud Armor security policies.

       Security policies are used to control access to Google Cloud
       HTTP/HTTPS load balancers.

       For more information about security policies, see
       [Security policies for HTTPS load balancing](https://cloud.google.com/armor/docs/security-policy-concepts#security_policies_for_https_load_balancing).

       See also: [Security policies API](https://cloud.google.com/compute/docs/reference/rest/v1/securityPolicies).
    """,
}

==> google-cloud-sdk-559.0.0-darwin-arm.tar.gz: google-cloud-sdk/lib/surface/compute/security_policies/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2017 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Commands for reading and manipulating security policies."""


from googlecloudsdk.calliope import base


@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
class SecurityPolicies(base.Group):
  """Read and manipulate Cloud Armor security policies."""
  pass


SecurityPolicies.category = base.LOAD_BALANCING_CATEGORY

SecurityPolicies.detailed_help = {
    'DESCRIPTION': """
       Read and manipulate Cloud Armor security policies.

       Security policies are used to control access to Google Cloud
       HTTP/HTTPS load balancers.

       For more information about security policies, see
       [Security policies for HTTPS load balancing](https://cloud.google.com/armor/docs/security-policy-concepts#security_policies_for_https_load_balancing).

       See also: [Security policies API](https://cloud.google.com/compute/docs/reference/rest/v1/securityPolicies).
    """,
}
